bibliotheca Augustana

<<< Übersicht <<< vorige Seite nächste Seite >>>
BIBLIOTHECA AUGUSTANA

Das Nibelungenlied

1190/1200

| # Handschrift B ## 1. Aventiure
___________________________________________________
| ### En> Bvrgonden ein vil edel magedin ### daz in allen landen niht schoners mohte sin ### Chriemhilt geheizen si wart ein scoene wip ### dar vmbe mvosen degene vil verliesen den lip ### Ir pflagen drie kvnege edel vn– rich ### Gventher vnde Gernot. di rechen lobelich ### vn– Giselher der ivnge ein voz erwelter degn ### div frovwe was ir swester di fversten hetens in ir pflægn ### Di herren waren milte. von arde hohe erborn ### mit chraft vnmâzen chvene. di rechen voz erchorn ### da zen Bvrgonden so was ir lant genant ### si frvmten starchiv wnder sit in Ezelen lant
###### 4 | ### Ze Wormeze bi dem Rine si wonten mit ir chraft ### in diente von ir landen. vil stolziv ritterscaft ### mit lobelichen eren. vnz an ir endes zit ### si erstvrben sit iæmerliche. von zweier edelen frowen nit
###### 5 | ### Ein richiv kvneginne frov Vote ir mvoter hiez ### ir vater der hiez Danchrat der in div erbe liez ### sit nach sime lebene ein ellens richer man ### der ovch in siner ivgende grozer eren vil gewan
###### 6 | ### Die drîe kvnege waren als ich gesaget han ### von vil hohem ellen in waren vndertan ### ovch di besten rechen von den man hat gesagt ### starch vn– vil chvene in scarpfen striten vnverzagt
###### 7 | ### Daz was von Tronege Hagene vn– ovch der brvoder sin ### Danchwart der vil snelle von Metzzen Ortewin ### die zwene marcgraven Gere vn– Ekkewart ### Volker von Alzeye mit ganzem ellen wol bewart
###### 8 | ### Rvomolt der chvchen meister ein tiwoerlicher degn ### Sindolt vn– Hvonolt dise herren mvosen pflegen ### des hoves vnt der eren der drîer kvnege man ### si heten noch manegen rechen des ich genennen niene chan
###### 9 | ### Danchwart der was marscalch do was der neve sin ### trvhsæze des kvneges von Metzzen Oertewin ### Sindolt der was scenche ein voz erwelter degn ### Hvonolt was chamerære si chvnden hoher eren pflegn
###### 10 | ### Von des hoves chrefte vn– von ir wîten chraft ### von ir vil hohen werdecheit vn– von ir ritterscaft ### der di herren pflagen mit vrovden all ir lebn ### des en chvnd iv ze ware niemen gar ein ende gebn
###### 11 | ### In disen hohen eren trovmte Chriemhilde ### wie si zvge einen valchen. starch scoen vn– wilde ### den ir zwene aren er [291b] chrvmmen daz si daz mvoste sehn ### ir en <chvnde> in dirre werlde leider nimmer gescehn
###### 12 | ### Den trovm si do sagete ir mvoter voten ### sine chvndes niht besceiden baz der gvoten ### der valche den dv zivhest daz ist ein edel man ### ine welle got behveten. dv mvost in sciere vloren han
###### 13 | ### Waz saget ir mir von manne. vil liebiv mvoter min ### ane rechen minne so wil ich immer sin ### svs scoen ich wil beliben. vnz an minen tot ### daz ich von mannes minne. sol gewinnen nimmer not
###### 14 | ### <Nv> versprich ez niht zesere. sprach aber ir mvoter do ### soltv immer hercenliche zer werlde werden vro ### daz gesciht von mannes minne. dv wirst ein scoene wip ### ob dir noch got gefveget. eins rehte gvoten ritters lip
###### 15 | ### Di rede lat beliben. sprach si frowe min ### ez ist an manegen wiben. vil diche worden scin ### wie liebe mit leide ze ivngest lonen chan ### ich sol si miden beide. sone chan mir nimmer missegan
###### 16 | ### Chriemhilt in ir mvote. sich minne gar bewach ### sit lebte div vil gvote. vil manegen lieben tach ### daz sine wesse niamen den minnen wolde ir lip ### sit wart si mit eren eins vil chvenen rechen wip
###### 17 | ### Der was der selbe valche. den si in ir trovme sach ### den ir besciet ir mvoter. wi sere si daz rach ### an ir næhsten magen. die in slvogen sint ### dvrch sin eines starben. starp vil maneger mvoter kint

<<< Übersicht <<< vorige Seite nächste Seite >>>